.. lesana documentation master file, created by
   sphinx-quickstart on Thu Oct  1 22:28:26 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

Documentation
-------------

The documentation for the latest development version of lesana can be
browsed online at https://lesana.trueelena.org; `PDF
<https://lesana.trueelena.org/lesana.pdf>`_ and `epub
<https://lesana.trueelena.org/lesana.epub>`_ versions are also
available.

The author can be contacted via email: webmaster AT trueelena DOT org.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started_command_line
   moving_data_between_collections
   promises

   man/index

   reference/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
